# Grand: Documentation

API reference documentation is available under `reference/` in this directory (https://github.com/aplbrain/grand/tree/master/docs/reference).

Reference documentation was generated with [Docshund](https://github.com/fitmango/docshund).
